@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class PIMDATAEXPORTER_EXPORT ArchiveStorage : public QObject
     Q_OBJECT
 public:
     explicit ArchiveStorage(const QString &filename, QObject *parent = nullptr);
-    ~ArchiveStorage();
+    ~ArchiveStorage() override;
 
     void closeArchive();
     Q_REQUIRED_RESULT bool openArchive(bool write);
