@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class ImportAlarmJobInterfaceTestImpl : public ImportAlarmJobInterface, public E
     Q_OBJECT
 public:
     explicit ImportAlarmJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportAlarmJobInterfaceTestImpl();
+    ~ImportAlarmJobInterfaceTestImpl() override;
 
     void setExistingPathConfig(const QString &path);
 protected:
