@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,10 +15,10 @@ BackupResourceFileJobImplTest::BackupResourceFileJobImplTest(QObject *parent)
 
 void BackupResourceFileJobImplTest::shouldHaveDefaultValue()
 {
-    auto *job = new BackupResourceFileJobImpl;
-    QVERIFY(!job->canStart());
-    QVERIFY(job->identifier().isEmpty());
-    QVERIFY(!job->zip());
-    QVERIFY(job->defaultPath().isEmpty());
-    delete job;
+  auto job = new BackupResourceFileJobImpl;
+  QVERIFY(!job->canStart());
+  QVERIFY(job->identifier().isEmpty());
+  QVERIFY(!job->zip());
+  QVERIFY(job->defaultPath().isEmpty());
+  delete job;
 }
