@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class ImportCalendarJobInterfaceTestImpl : public ImportCalendarJobInterface, pu
     Q_OBJECT
 public:
     explicit ImportCalendarJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportCalendarJobInterfaceTestImpl();
+    ~ImportCalendarJobInterfaceTestImpl() override;
 
     void setExistingPathConfig(const QString &path);
 protected:
