@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class LogCreatingResource : public QObject
     Q_OBJECT
 public:
     explicit LogCreatingResource(QObject *parent = nullptr);
-    ~LogCreatingResource();
+    ~LogCreatingResource() override;
     void appendText(const QString &str);
     Q_REQUIRED_RESULT QString logPath() const;
     Q_REQUIRED_RESULT QString logCreateResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree);
