@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class ExportMailJobInterfaceTestImpl : public ExportMailJobInterface, public Exp
     Q_OBJECT
 public:
     explicit ExportMailJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ExportMailJobInterfaceTestImpl();
+    ~ExportMailJobInterfaceTestImpl() override;
 
 protected:
     void convertCollectionToRealPath(KConfigGroup &group, const QString &currentKey) override;
