@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class ImportNotesJobInterfaceTest : public QObject
     Q_OBJECT
 public:
     explicit ImportNotesJobInterfaceTest(QObject *parent = nullptr);
-    ~ImportNotesJobInterfaceTest() = default;
+    ~ImportNotesJobInterfaceTest() override = default;
 private Q_SLOTS:
     void importNote();
     void importNote_data();
