@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class ImportNotesJobInterfaceTestImpl : public ImportNotesJobInterface, public E
     Q_OBJECT
 public:
     explicit ImportNotesJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportNotesJobInterfaceTestImpl();
+    ~ImportNotesJobInterfaceTestImpl() override;
     void setExistingPathConfig(const QString &path);
 
 protected:
