@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,7 +36,7 @@ void SynchronizeResourceJob::slotNextSync()
     if (mIndex < mListResources.count()) {
         const Akonadi::AgentInstance resource = Akonadi::AgentManager::self()->instance(mListResources.at(mIndex));
         qCDebug(PIMDATAEXPORTERCORE_LOG) << " resource.name" << resource.name();
-        auto *job = new Akonadi::ResourceSynchronizationJob(resource);
+        auto job = new Akonadi::ResourceSynchronizationJob(resource);
         job->setTimeoutCountLimit(10);
         job->setCollectionTreeOnly(mOnlyCollection);
         connect(job, &Akonadi::ResourceSynchronizationJob::result, this, &SynchronizeResourceJob::slotSynchronizationFinished);
@@ -48,13 +48,14 @@ void SynchronizeResourceJob::slotNextSync()
 
 void SynchronizeResourceJob::slotSynchronizationFinished(KJob *job)
 {
-    auto *resourceSync = qobject_cast<Akonadi::ResourceSynchronizationJob *>(job);
-    const QString instanceName = resourceSync->resource().name();
-    if (job->error()) {
-        Q_EMIT synchronizationInstanceFailed(instanceName);
-    } else {
-        Q_EMIT synchronizationInstanceDone(instanceName, resourceSync->resource().identifier());
-    }
+  auto resourceSync = qobject_cast<Akonadi::ResourceSynchronizationJob *>(job);
+  const QString instanceName = resourceSync->resource().name();
+  if (job->error()) {
+    Q_EMIT synchronizationInstanceFailed(instanceName);
+  } else {
+    Q_EMIT synchronizationInstanceDone(instanceName,
+                                       resourceSync->resource().identifier());
+  }
     ++mIndex;
     QTimer::singleShot(0, this, &SynchronizeResourceJob::slotNextSync);
 }
