@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include <KLocalizedString>
 #include <QPushButton>
 #include <QDialogButtonBox>
-#include <kpagewidgetmodel.h>
+#include <KPageWidgetModel>
 #include "../widgets/pimdataexporterconfigurewidget.h"
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -28,7 +28,7 @@ PimDataExporterConfigureDialog::PimDataExporterConfigureDialog(QWidget *parent)
 
     //General page
     QWidget *generalConfigureWiget = new QWidget;
-    auto *layout = new QVBoxLayout(generalConfigureWiget);
+    auto layout = new QVBoxLayout(generalConfigureWiget);
     mConfigureWidget = new PimDataExporterConfigureWidget(this);
     mConfigureWidget->setObjectName(QStringLiteral("configurewidget"));
 
@@ -44,7 +44,7 @@ PimDataExporterConfigureDialog::PimDataExporterConfigureDialog(QWidget *parent)
 
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
 
-    auto *userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
+    auto userFeedBackLayout = new QHBoxLayout(userFeedBackWidget);
     userFeedBackLayout->setContentsMargins(0, 0, 0, 0);
     userFeedBackLayout->addWidget(mUserFeedbackWidget);
 
