@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SynchronizeResourceDialog : public QDialog
     Q_OBJECT
 public:
     explicit SynchronizeResourceDialog(QWidget *parent = nullptr);
-    ~SynchronizeResourceDialog();
+    ~SynchronizeResourceDialog() override;
 
     void setResources(const QHash<QString, QString> &resources);
     Q_REQUIRED_RESULT QStringList resources() const;
