@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef PIMDATAEXPORTERWINDOW_H
 #define PIMDATAEXPORTERWINDOW_H
-#include <kxmlguiwindow.h>
+#include <KXmlGuiWindow>
 #include "utils.h"
 class LogWidget;
 class KRecentFilesAction;
@@ -19,7 +19,7 @@ class PimDataExporterWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit PimDataExporterWindow(QWidget *parent = nullptr);
-    ~PimDataExporterWindow();
+    ~PimDataExporterWindow() override;
     void handleCommandLine(const QCommandLineParser &parser);
 
 private:
