@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ class SelectionTypeTreeWidget : public QTreeWidget
     Q_OBJECT
 public:
     explicit SelectionTypeTreeWidget(bool backupData, QWidget *parent = nullptr);
-    ~SelectionTypeTreeWidget();
+    ~SelectionTypeTreeWidget() override;
 
     Q_REQUIRED_RESULT QHash<Utils::AppsType, Utils::importExportParameters> storedType() const;
 
